@@ -16,11 +16,11 @@ from rest_framework.exceptions import ValidationError
 class Client:
     """TranslateClient utils class."""
 
-    CACHE_VIEW_TTL = 60 * 45
-    CACHE_OCCURRENCE_TTL = 60 * 45
-    CACHE_GROUP_KEY_TTL = 60 * 45
+    CACHE_VIEW_TTL = config("CACHE_VIEW_TTL", default=2700, cast=int)
+    CACHE_OCCURRENCE_TTL = config("CACHE_OCCURRENCE_TTL", default=2700, cast=int)
+    CACHE_GROUP_KEY_TTL = config("CACHE_GROUP_KEY_TTL", default=2700, cast=int)
 
-    timeout = int(config("REQUESTS_TIMEOUT", default=30))
+    timeout = config("REQUESTS_TIMEOUT", default=30, cast=int)
 
     __instance = None
 
